[Scummvm-cvs-logs] SF.net SVN: scummvm: [20968] tools/trunk/descumm.cpp

kirben at users.sourceforge.net kirben at users.sourceforge.net
Mon Feb 27 23:01:02 CET 2006


Revision: 20968
Author:   kirben
Date:     2006-02-27 23:00:48 -0800 (Mon, 27 Feb 2006)
ViewCVS:  http://svn.sourceforge.net/scummvm?rev=20968&view=rev

Log Message:
-----------
Sync. opcodes names for actorOps

Modified Paths:
--------------
    tools/trunk/descumm.cpp
Modified: tools/trunk/descumm.cpp
===================================================================
--- tools/trunk/descumm.cpp	2006-02-28 01:14:02 UTC (rev 20967)
+++ tools/trunk/descumm.cpp	2006-02-28 07:00:48 UTC (rev 20968)
@@ -693,11 +693,11 @@
 	*buf = 0;
 }
 
-void do_actorset_v12(char *buf, byte opcode)
+void do_actorops_v12(char *buf, byte opcode)
 {
 	// FIXME: the A2 should be displayed as arg to the subops, not as arg to the
-	// ActorSet itself; but that'll require some more work.
-	buf = do_tok(buf, "ActorSet", ((opcode & 0x80) ? A1V : A1B) | ((opcode & 0x80) ? A2V : A2B) | ANOLASTPAREN);
+	// ActorOps itself; but that'll require some more work.
+	buf = do_tok(buf, "ActorOps", ((opcode & 0x80) ? A1V : A1B) | ((opcode & 0x80) ? A2V : A2B) | ANOLASTPAREN);
 	buf = strecpy(buf, ",[");
 
 	int subop = get_byte();
@@ -1956,7 +1956,7 @@
 	case 0x93:
 	case 0xD3:
 		// actorSet
-		do_actorset_v12(buf, opcode);
+		do_actorops_v12(buf, opcode);
 		break;
 
 	case 0x2A:







More information about the Scummvm-git-logs mailing list